# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x64oublecloud/v1/cluster.proto\x12\x0e\x64oublecloud.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xb8\x04\n\x06\x41\x63\x63\x65ss\x12N\n\x10ipv4_cidr_blocks\x18\x01 \x01(\x0b\x32$.doublecloud.v1.Access.CidrBlockListR\x0eipv4CidrBlocks\x12N\n\x10ipv6_cidr_blocks\x18\x02 \x01(\x0b\x32$.doublecloud.v1.Access.CidrBlockListR\x0eipv6CidrBlocks\x12K\n\rdata_services\x18\x03 \x01(\x0b\x32&.doublecloud.v1.Access.DataServiceListR\x0c\x64\x61taServices\x1a\x43\n\tCidrBlock\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x1aI\n\rCidrBlockList\x12\x38\n\x06values\x18\x01 \x03(\x0b\x32 .doublecloud.v1.Access.CidrBlockR\x06values\x1aM\n\x0f\x44\x61taServiceList\x12:\n\x06values\x18\x01 \x03(\x0e\x32\".doublecloud.v1.Access.DataServiceR\x06values\"b\n\x0b\x44\x61taService\x12\x18\n\x14\x44\x41TA_SERVICE_INVALID\x10\x00\x12\x1e\n\x1a\x44\x41TA_SERVICE_VISUALIZATION\x10\x01\x12\x19\n\x15\x44\x41TA_SERVICE_TRANSFER\x10\x02\"F\n\x0e\x44\x61taEncryption\x12\x34\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x07\x65nabled*\xc1\x02\n\rClusterStatus\x12\x1a\n\x16\x43LUSTER_STATUS_INVALID\x10\x00\x12\x18\n\x14\x43LUSTER_STATUS_ALIVE\x10\x01\x12\x1b\n\x17\x43LUSTER_STATUS_DEGRADED\x10\x02\x12\x17\n\x13\x43LUSTER_STATUS_DEAD\x10\x03\x12\x1a\n\x16\x43LUSTER_STATUS_UNKNOWN\x10\x04\x12\x1b\n\x17\x43LUSTER_STATUS_CREATING\x10\x05\x12\x1b\n\x17\x43LUSTER_STATUS_UPDATING\x10\x06\x12\x1b\n\x17\x43LUSTER_STATUS_STOPPING\x10\x07\x12\x1a\n\x16\x43LUSTER_STATUS_STOPPED\x10\x08\x12\x1b\n\x17\x43LUSTER_STATUS_STARTING\x10\t\x12\x18\n\x14\x43LUSTER_STATUS_ERROR\x10\n*l\n\nHostStatus\x12\x17\n\x13HOST_STATUS_INVALID\x10\x00\x12\x15\n\x11HOST_STATUS_ALIVE\x10\x01\x12\x14\n\x10HOST_STATUS_DEAD\x10\x02\x12\x18\n\x14HOST_STATUS_DEGRADED\x10\x03\x42\x37Z5github.com/doublecloud/api/doublecloud/v1;doublecloudb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/v1;doublecloud'
  _globals['_CLUSTERSTATUS']._serialized_start=724
  _globals['_CLUSTERSTATUS']._serialized_end=1045
  _globals['_HOSTSTATUS']._serialized_start=1047
  _globals['_HOSTSTATUS']._serialized_end=1155
  _globals['_ACCESS']._serialized_start=81
  _globals['_ACCESS']._serialized_end=649
  _globals['_ACCESS_CIDRBLOCK']._serialized_start=328
  _globals['_ACCESS_CIDRBLOCK']._serialized_end=395
  _globals['_ACCESS_CIDRBLOCKLIST']._serialized_start=397
  _globals['_ACCESS_CIDRBLOCKLIST']._serialized_end=470
  _globals['_ACCESS_DATASERVICELIST']._serialized_start=472
  _globals['_ACCESS_DATASERVICELIST']._serialized_end=549
  _globals['_ACCESS_DATASERVICE']._serialized_start=551
  _globals['_ACCESS_DATASERVICE']._serialized_end=649
  _globals['_DATAENCRYPTION']._serialized_start=651
  _globals['_DATAENCRYPTION']._serialized_end=721
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/v1/paging.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64oublecloud/v1/paging.proto\x12\x0e\x64oublecloud.v1\"D\n\x06Paging\x12\x1b\n\tpage_size\x18\x01 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\" \n\x08NextPage\x12\x14\n\x05token\x18\x01 \x01(\tR\x05tokenB7Z5github.com/doublecloud/api/doublecloud/v1;doublecloudb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.v1.paging_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/v1;doublecloud'
  _globals['_PAGING']._serialized_start=47
  _globals['_PAGING']._serialized_end=115
  _globals['_NEXTPAGE']._serialized_start=117
  _globals['_NEXTPAGE']._serialized_end=149
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.clickhouse.v1 import backup_pb2 as doublecloud_dot_clickhouse_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.doublecloud/clickhouse/v1/backup_service.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a&doublecloud/clickhouse/v1/backup.proto\"/\n\x10GetBackupRequest\x12\x1b\n\tbackup_id\x18\x01 \x01(\tR\x08\x62\x61\x63kupId\"c\n\x12ListBackupsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x89\x01\n\x13ListBackupsResponse\x12;\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32!.doublecloud.clickhouse.v1.BackupR\x07\x62\x61\x63kups\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"H\n\x13\x43reateBackupRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"2\n\x13\x44\x65leteBackupRequest\x12\x1b\n\tbackup_id\x18\x01 \x01(\tR\x08\x62\x61\x63kupId2\xf7\x02\n\rBackupService\x12U\n\x03Get\x12+.doublecloud.clickhouse.v1.GetBackupRequest\x1a!.doublecloud.clickhouse.v1.Backup\x12\x65\n\x04List\x12-.doublecloud.clickhouse.v1.ListBackupsRequest\x1a..doublecloud.clickhouse.v1.ListBackupsResponse\x12S\n\x06\x43reate\x12..doublecloud.clickhouse.v1.CreateBackupRequest\x1a\x19.doublecloud.v1.Operation\x12S\n\x06\x44\x65lete\x12..doublecloud.clickhouse.v1.DeleteBackupRequest\x1a\x19.doublecloud.v1.OperationBAZ?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _globals['_GETBACKUPREQUEST']._serialized_start=178
  _globals['_GETBACKUPREQUEST']._serialized_end=225
  _globals['_LISTBACKUPSREQUEST']._serialized_start=227
  _globals['_LISTBACKUPSREQUEST']._serialized_end=326
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=329
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=466
  _globals['_CREATEBACKUPREQUEST']._serialized_start=468
  _globals['_CREATEBACKUPREQUEST']._serialized_end=540
  _globals['_DELETEBACKUPREQUEST']._serialized_start=542
  _globals['_DELETEBACKUPREQUEST']._serialized_end=592
  _globals['_BACKUPSERVICE']._serialized_start=595
  _globals['_BACKUPSERVICE']._serialized_end=970
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from doublecloud.transfer.v1 import endpoint_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.doublecloud/transfer/v1/endpoint_service.proto\x12\x17\x64oublecloud.transfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&doublecloud/transfer/v1/endpoint.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"5\n\x12GetEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\x01 \x01(\tR\nendpointId\"a\n\x14ListEndpointsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12*\n\x04page\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x04page\"\x8f\x01\n\x15ListEndpointsResponse\x12?\n\tendpoints\x18\x01 \x03(\x0b\x32!.doublecloud.transfer.v1.EndpointR\tendpoints\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xc2\x02\n\x15\x43reateEndpointRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12R\n\x06labels\x18\x04 \x03(\x0b\x32:.doublecloud.transfer.v1.CreateEndpointRequest.LabelsEntryR\x06labels\x12\x45\n\x08settings\x18\x34 \x01(\x0b\x32).doublecloud.transfer.v1.EndpointSettingsR\x08settings\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc4\x02\n\x15UpdateEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\n \x01(\tR\nendpointId\x12\x12\n\x04name\x18\x0b \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12R\n\x06labels\x18\r \x03(\x0b\x32:.doublecloud.transfer.v1.UpdateEndpointRequest.LabelsEntryR\x06labels\x12\x45\n\x08settings\x18\x34 \x01(\x0b\x32).doublecloud.transfer.v1.EndpointSettingsR\x08settings\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"8\n\x15\x44\x65leteEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\x01 \x01(\tR\nendpointId2\x80\x05\n\x0f\x45ndpointService\x12y\n\x03Get\x12+.doublecloud.transfer.v1.GetEndpointRequest\x1a!.doublecloud.transfer.v1.Endpoint\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/endpoint/{endpoint_id}\x12\x8e\x01\n\x04List\x12-.doublecloud.transfer.v1.ListEndpointsRequest\x1a..doublecloud.transfer.v1.ListEndpointsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/endpoints/list/{project_id}\x12l\n\x06\x43reate\x12..doublecloud.transfer.v1.CreateEndpointRequest\x1a\x19.doublecloud.v1.Operation\"\x17\x82\xd3\xe4\x93\x02\x11:\x01*\"\x0c/v1/endpoint\x12z\n\x06Update\x12..doublecloud.transfer.v1.UpdateEndpointRequest\x1a\x19.doublecloud.v1.Operation\"%\x82\xd3\xe4\x93\x02\x1f:\x01*2\x1a/v1/endpoint/{endpoint_id}\x12w\n\x06\x44\x65lete\x12..doublecloud.transfer.v1.DeleteEndpointRequest\x1a\x19.doublecloud.v1.Operation\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/endpoint/{endpoint_id}B=Z;github.com/doublecloud/api/doublecloud/transfer/v1;transferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/doublecloud/api/doublecloud/transfer/v1;transfer'
  _CREATEENDPOINTREQUEST_LABELSENTRY._options = None
  _CREATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEENDPOINTREQUEST_LABELSENTRY._options = None
  _UPDATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ENDPOINTSERVICE.methods_by_name['Get']._options = None
  _ENDPOINTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['List']._options = None
  _ENDPOINTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/v1/endpoints/list/{project_id}'
  _ENDPOINTSERVICE.methods_by_name['Create']._options = None
  _ENDPOINTSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\021:\001*\"\014/v1/endpoint'
  _ENDPOINTSERVICE.methods_by_name['Update']._options = None
  _ENDPOINTSERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\037:\001*2\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['Delete']._options = None
  _ENDPOINTSERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\034*\032/v1/endpoint/{endpoint_id}'
  _globals['_GETENDPOINTREQUEST']._serialized_start=240
  _globals['_GETENDPOINTREQUEST']._serialized_end=293
  _globals['_LISTENDPOINTSREQUEST']._serialized_start=295
  _globals['_LISTENDPOINTSREQUEST']._serialized_end=392
  _globals['_LISTENDPOINTSRESPONSE']._serialized_start=395
  _globals['_LISTENDPOINTSRESPONSE']._serialized_end=538
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=541
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=863
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=806
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=863
  _globals['_UPDATEENDPOINTREQUEST']._serialized_start=866
  _globals['_UPDATEENDPOINTREQUEST']._serialized_end=1190
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=806
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=863
  _globals['_DELETEENDPOINTREQUEST']._serialized_start=1192
  _globals['_DELETEENDPOINTREQUEST']._serialized_end=1248
  _globals['_ENDPOINTSERVICE']._serialized_start=1251
  _globals['_ENDPOINTSERVICE']._serialized_end=1891
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-doublecloud/transfer/v1/endpoint/common.proto\x12 doublecloud.transfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\"?\n\x07\x41ltName\x12\x1b\n\tfrom_name\x18\x01 \x01(\tR\x08\x66romName\x12\x17\n\x07to_name\x18\x02 \x01(\tR\x06toName\"%\n\x06Secret\x12\x12\n\x03raw\x18\x01 \x01(\tH\x00R\x03rawB\x07\n\x05value\"\xa3\x01\n\tColSchema\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12@\n\x04type\x18\x02 \x01(\x0e\x32,.doublecloud.transfer.v1.endpoint.ColumnTypeR\x04type\x12\x10\n\x03key\x18\x03 \x01(\x08R\x03key\x12\x1a\n\x08required\x18\x04 \x01(\x08R\x08required\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\"\x94\x01\n\x07TLSMode\x12\x34\n\x08\x64isabled\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x08\x64isabled\x12G\n\x07\x65nabled\x18\x02 \x01(\x0b\x32+.doublecloud.transfer.v1.endpoint.TLSConfigH\x00R\x07\x65nabledB\n\n\x08tls_mode\"2\n\tTLSConfig\x12%\n\x0e\x63\x61_certificate\x18\x01 \x01(\tR\rcaCertificate\";\n\x0b\x43olumnValue\x12#\n\x0cstring_value\x18\x01 \x01(\tH\x00R\x0bstringValueB\x07\n\x05value\"P\n\tFieldList\x12\x43\n\x06\x66ields\x18\x02 \x03(\x0b\x32+.doublecloud.transfer.v1.endpoint.ColSchemaR\x06\x66ields\"\x80\x01\n\nDataSchema\x12\x45\n\x06\x66ields\x18\x02 \x01(\x0b\x32+.doublecloud.transfer.v1.endpoint.FieldListH\x00R\x06\x66ields\x12!\n\x0bjson_fields\x18\x01 \x01(\tH\x00R\njsonFieldsB\x08\n\x06schema\"\x08\n\x06NoAuth*h\n\x13ObjectTransferStage\x12%\n!OBJECT_TRANSFER_STAGE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x42\x45\x46ORE_DATA\x10\x01\x12\x0e\n\nAFTER_DATA\x10\x02\x12\t\n\x05NEVER\x10\x03*U\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x08\n\x04\x44ROP\x10\x02\x12\x0c\n\x08TRUNCATE\x10\x03*\xc9\x01\n\nColumnType\x12\x1b\n\x17\x43OLUMN_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05INT64\x10\x0e\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT16\x10\x02\x12\x08\n\x04INT8\x10\x03\x12\n\n\x06UINT64\x10\x04\x12\n\n\x06UINT32\x10\x05\x12\n\n\x06UINT16\x10\x06\x12\t\n\x05UINT8\x10\x07\x12\n\n\x06\x44OUBLE\x10\x08\x12\x0b\n\x07\x42OOLEAN\x10\t\x12\n\n\x06STRING\x10\n\x12\x08\n\x04UTF8\x10\x0b\x12\x07\n\x03\x41NY\x10\x0c\x12\x0c\n\x08\x44\x41TETIME\x10\rBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_OBJECTTRANSFERSTAGE']._serialized_start=869
  _globals['_OBJECTTRANSFERSTAGE']._serialized_end=973
  _globals['_CLEANUPPOLICY']._serialized_start=975
  _globals['_CLEANUPPOLICY']._serialized_end=1060
  _globals['_COLUMNTYPE']._serialized_start=1063
  _globals['_COLUMNTYPE']._serialized_end=1264
  _globals['_ALTNAME']._serialized_start=112
  _globals['_ALTNAME']._serialized_end=175
  _globals['_SECRET']._serialized_start=177
  _globals['_SECRET']._serialized_end=214
  _globals['_COLSCHEMA']._serialized_start=217
  _globals['_COLSCHEMA']._serialized_end=380
  _globals['_TLSMODE']._serialized_start=383
  _globals['_TLSMODE']._serialized_end=531
  _globals['_TLSCONFIG']._serialized_start=533
  _globals['_TLSCONFIG']._serialized_end=583
  _globals['_COLUMNVALUE']._serialized_start=585
  _globals['_COLUMNVALUE']._serialized_end=644
  _globals['_FIELDLIST']._serialized_start=646
  _globals['_FIELDLIST']._serialized_end=726
  _globals['_DATASCHEMA']._serialized_start=729
  _globals['_DATASCHEMA']._serialized_end=857
  _globals['_NOAUTH']._serialized_start=859
  _globals['_NOAUTH']._serialized_end=867
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/network/v1/network_connection_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.network.v1 import network_connection_pb2 as doublecloud_dot_network_dot_v1_dot_network__connection__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7doublecloud/network/v1/network_connection_service.proto\x12\x16\x64oublecloud.network.v1\x1a/doublecloud/network/v1/network_connection.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"Q\n\x1bGetNetworkConnectionRequest\x12\x32\n\x15network_connection_id\x18\x01 \x01(\tR\x13networkConnectionId\"n\n\x1dListNetworkConnectionsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\xb3\x01\n\x1eListNetworkConnectionsResponse\x12Z\n\x13network_connections\x18\x01 \x03(\x0b\x32).doublecloud.network.v1.NetworkConnectionR\x12networkConnections\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xba\x01\n\x1e\x43reateNetworkConnectionRequest\x12\x1d\n\nnetwork_id\x18\x01 \x01(\tR\tnetworkId\x12M\n\x03\x61ws\x18\x03 \x01(\x0b\x32\x39.doublecloud.network.v1.CreateAWSNetworkConnectionRequestH\x00R\x03\x61ws\x12 \n\x0b\x64\x65scription\x18\x06 \x01(\tR\x0b\x64\x65scriptionB\x08\n\x06params\"\x89\x01\n!CreateAWSNetworkConnectionRequest\x12\\\n\x07peering\x18\x01 \x01(\x0b\x32@.doublecloud.network.v1.CreateAWSNetworkConnectionPeeringRequestH\x00R\x07peeringB\x06\n\x04type\"\xcd\x01\n(CreateAWSNetworkConnectionPeeringRequest\x12\x15\n\x06vpc_id\x18\x01 \x01(\tR\x05vpcId\x12\x1d\n\naccount_id\x18\x02 \x01(\tR\taccountId\x12\x1b\n\tregion_id\x18\x03 \x01(\tR\x08regionId\x12&\n\x0fipv4_cidr_block\x18\x04 \x01(\tR\ripv4CidrBlock\x12&\n\x0fipv6_cidr_block\x18\x05 \x01(\tR\ripv6CidrBlock\"T\n\x1e\x44\x65leteNetworkConnectionRequest\x12\x32\n\x15network_connection_id\x18\x01 \x01(\tR\x13networkConnectionId\"v\n\x1eUpdateNetworkConnectionRequest\x12\x32\n\x15network_connection_id\x18\x01 \x01(\tR\x13networkConnectionId\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription2\xb2\x03\n\x18NetworkConnectionService\x12\x65\n\x03Get\x12\x33.doublecloud.network.v1.GetNetworkConnectionRequest\x1a).doublecloud.network.v1.NetworkConnection\x12u\n\x04List\x12\x35.doublecloud.network.v1.ListNetworkConnectionsRequest\x1a\x36.doublecloud.network.v1.ListNetworkConnectionsResponse\x12[\n\x06\x43reate\x12\x36.doublecloud.network.v1.CreateNetworkConnectionRequest\x1a\x19.doublecloud.v1.Operation\x12[\n\x06\x44\x65lete\x12\x36.doublecloud.network.v1.DeleteNetworkConnectionRequest\x1a\x19.doublecloud.v1.OperationB;Z9github.com/doublecloud/api/doublecloud/network/v1;networkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.network.v1.network_connection_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/doublecloud/api/doublecloud/network/v1;network'
  _globals['_GETNETWORKCONNECTIONREQUEST']._serialized_start=193
  _globals['_GETNETWORKCONNECTIONREQUEST']._serialized_end=274
  _globals['_LISTNETWORKCONNECTIONSREQUEST']._serialized_start=276
  _globals['_LISTNETWORKCONNECTIONSREQUEST']._serialized_end=386
  _globals['_LISTNETWORKCONNECTIONSRESPONSE']._serialized_start=389
  _globals['_LISTNETWORKCONNECTIONSRESPONSE']._serialized_end=568
  _globals['_CREATENETWORKCONNECTIONREQUEST']._serialized_start=571
  _globals['_CREATENETWORKCONNECTIONREQUEST']._serialized_end=757
  _globals['_CREATEAWSNETWORKCONNECTIONREQUEST']._serialized_start=760
  _globals['_CREATEAWSNETWORKCONNECTIONREQUEST']._serialized_end=897
  _globals['_CREATEAWSNETWORKCONNECTIONPEERINGREQUEST']._serialized_start=900
  _globals['_CREATEAWSNETWORKCONNECTIONPEERINGREQUEST']._serialized_end=1105
  _globals['_DELETENETWORKCONNECTIONREQUEST']._serialized_start=1107
  _globals['_DELETENETWORKCONNECTIONREQUEST']._serialized_end=1191
  _globals['_UPDATENETWORKCONNECTIONREQUEST']._serialized_start=1193
  _globals['_UPDATENETWORKCONNECTIONREQUEST']._serialized_end=1311
  _globals['_NETWORKCONNECTIONSERVICE']._serialized_start=1314
  _globals['_NETWORKCONNECTIONSERVICE']._serialized_end=1748
# @@protoc_insertion_point(module_scope)



import time
from datetime import datetime

# noinspection PyUnresolvedReferences
# jwt package depends on cryptography
import cryptography  # noqa: F401; pylint: disable=unused-import
import jwt
import requests
import six

from doublecloud import _consts as const


def __validate_service_account_key(sa_key):
    if not isinstance(sa_key, dict):
        actual_type = type(sa_key)
        raise RuntimeError(f"Invalid Service Account Key: expecting dictionary, actually got {actual_type}")

    obj_id = sa_key.get("id")
    sa_id = sa_key.get("service_account_id")
    private_key = sa_key.get("private_key")

    if not obj_id:
        raise RuntimeError("Invalid Service Account Key: missing key object id.")

    if not sa_id:
        raise RuntimeError("Invalid Service Account Key: missing service account id.")

    if not private_key:
        raise RuntimeError("Invalid Service Account Key: missing private key.")

    private_key_prefix = "-----BEGIN PRIVATE KEY-----"
    if not isinstance(private_key, six.string_types) or not private_key.startswith(private_key_prefix):
        error_message = (
            "Invalid Service Account Key: private key is in incorrect format."
            + f"Should start with {private_key_prefix}.\n"
        )
        raise RuntimeError(error_message)


def get_auth_token_requester(service_account_key=None, iam_token=None, endpoint=None, user_agent=None):
    if endpoint is None:
        endpoint = const.get_endpoint()
    auth_methods = [("service_account_key", service_account_key), ("iam_token", iam_token)]
    auth_methods = [(auth_type, value) for auth_type, value in auth_methods if value is not None]

    if not auth_methods:
        raise RuntimeError("Auth method didn't provided, credentials are unset.")

    if len(auth_methods) > 1:
        properties = [auth[0] for auth in auth_methods]
        raise RuntimeError(f"Conflicting API credentials properties are set: {properties}.")

    auth_name, _ = auth_methods[0]
    if auth_name == "service_account_key":
        __validate_service_account_key(service_account_key)
        return ServiceAccountAuth(service_account_key, endpoint, user_agent)
    if auth_name == "iam_token":
        return IamTokenAuth(iam_token)

    raise RuntimeError(f"Unknown auth method: {auth_name}")


class ServiceAccountAuth:
    __SECONDS_IN_HOUR = 60.0 * 60.0

    def __init__(self, sa_key, endpoint=None, user_agent=const.SDK_USER_AGENT):
        self.__sa_key = sa_key
        if endpoint is None:
            endpoint = const.get_endpoint()
        self._endpoint = endpoint
        self._user_agent = user_agent

    def get_token(self):
        headers = {"Content-Type": "application/x-www-form-urlencoded"}
        if self._user_agent:
            headers["User-Agent"] = self._user_agent

        assertion = self.get_token_request()
        r = requests.post(
            f"https://auth.{self._endpoint}/oauth/token",
            headers=headers,
            data=f"grant_type=urn:ietf:params:oauth:grant-type:jwt-bearer&assertion={assertion}",
            timeout=30.0,
        )
        r.raise_for_status()
        return r.json()["access_token"]

    def get_token_request(self):
        now = time.time()
        now_utc = datetime.utcfromtimestamp(now)
        exp_utc = datetime.utcfromtimestamp(now + self.__SECONDS_IN_HOUR)
        aud = f"https://auth.{self._endpoint}/oauth/token"
        payload = {
            "iss": self.__sa_key["service_account_id"],
            "sub": self.__sa_key["service_account_id"],
            "aud": aud,
            "iat": now_utc,
            "exp": exp_utc,
        }

        headers = {
            "typ": "JWT",
            "alg": "PS256",
            "kid": self.__sa_key["id"],
        }

        return jwt.encode(payload, self.__sa_key["private_key"], algorithm="PS256", headers=headers)


class IamTokenAuth:
    def __init__(self, iam_token):
        self.__iam_token = iam_token

    def get_token(self):
        return self.__iam_token



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/google_ads_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@doublecloud/transfer/v1/endpoint/airbyte/google_ads_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"\xc3\x04\n\x0fGoogleAdsSource\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nstart_date\x18\x02 \x01(\tR\tstartDate\x12\x19\n\x08\x65nd_date\x18\x03 \x01(\tR\x07\x65ndDate\x12l\n\x0e\x63ustom_queries\x18\x04 \x03(\x0b\x32\x45.doublecloud.transfer.v1.endpoint.airbyte.GoogleAdsSource.CustomQueryR\rcustomQueries\x12*\n\x11login_customer_id\x18\x05 \x01(\tR\x0floginCustomerId\x12\x34\n\x16\x63onversion_window_days\x18\x06 \x01(\x01R\x14\x63onversionWindowDays\x1a\x42\n\x0b\x43ustomQuery\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x1d\n\ntable_name\x18\x02 \x01(\tR\ttableName\x1a\xc0\x01\n\x0b\x43redentials\x12\'\n\x0f\x64\x65veloper_token\x18\x01 \x01(\tR\x0e\x64\x65veloperToken\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12#\n\rclient_secret\x18\x03 \x01(\tR\x0c\x63lientSecret\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12#\n\rrefresh_token\x18\x05 \x01(\tR\x0crefreshTokenBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.google_ads_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_GOOGLEADSSOURCE']._serialized_start=111
  _globals['_GOOGLEADSSOURCE']._serialized_end=690
  _globals['_GOOGLEADSSOURCE_CUSTOMQUERY']._serialized_start=429
  _globals['_GOOGLEADSSOURCE_CUSTOMQUERY']._serialized_end=495
  _globals['_GOOGLEADSSOURCE_CREDENTIALS']._serialized_start=498
  _globals['_GOOGLEADSSOURCE_CREDENTIALS']._serialized_end=690
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&doublecloud/clickhouse/v1/config.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf1+\n\x10\x43lickhouseConfig\x12Q\n\tlog_level\x18\x01 \x01(\x0e\x32\x34.doublecloud.clickhouse.v1.ClickhouseConfig.LogLevelR\x08logLevel\x12\x44\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0emaxConnections\x12Q\n\x16max_concurrent_queries\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14maxConcurrentQueries\x12G\n\x12keep_alive_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10keepAliveTimeout\x12S\n\x17uncompressed_cache_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15uncompressedCacheSize\x12\x43\n\x0fmark_cache_size\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\rmarkCacheSize\x12O\n\x16max_table_size_to_drop\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12maxTableSizeToDrop\x12W\n\x1amax_partition_size_to_drop\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x16maxPartitionSizeToDrop\x12\x38\n\x08timezone\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08timezone\x12M\n\x14\x62\x61\x63kground_pool_size\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12\x62\x61\x63kgroundPoolSize\x12^\n\x1d\x62\x61\x63kground_schedule_pool_size\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1a\x62\x61\x63kgroundSchedulePoolSize\x12\\\n\x1c\x62\x61\x63kground_fetches_pool_size\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x19\x62\x61\x63kgroundFetchesPoolSize\x12V\n\x19\x62\x61\x63kground_move_pool_size\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x16\x62\x61\x63kgroundMovePoolSize\x12Z\n\x1b\x62\x61\x63kground_common_pool_size\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x18\x62\x61\x63kgroundCommonPoolSize\x12}\n-background_merges_mutations_concurrency_ratio\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR)backgroundMergesMutationsConcurrencyRatio\x12X\n\x1atotal_memory_profiler_step\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x17totalMemoryProfilerStep\x12r\n\'total_memory_tracker_sample_probability\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR#totalMemoryTrackerSampleProbability\x12T\n\nmerge_tree\x18\x11 \x01(\x0b\x32\x35.doublecloud.clickhouse.v1.ClickhouseConfig.MergeTreeR\tmergeTree\x12Y\n\x0b\x63ompression\x18\x12 \x03(\x0b\x32\x37.doublecloud.clickhouse.v1.ClickhouseConfig.CompressionR\x0b\x63ompression\x12h\n\x0fgraphite_rollup\x18\x13 \x03(\x0b\x32?.doublecloud.clickhouse.v1.ClickhouseConfig.GraphiteRollupEntryR\x0egraphiteRollup\x12G\n\x05kafka\x18\x14 \x01(\x0b\x32\x31.doublecloud.clickhouse.v1.ClickhouseConfig.KafkaR\x05kafka\x12_\n\x0ckafka_topics\x18\x15 \x03(\x0b\x32<.doublecloud.clickhouse.v1.ClickhouseConfig.KafkaTopicsEntryR\x0bkafkaTopics\x12P\n\x08rabbitmq\x18\x16 \x01(\x0b\x32\x34.doublecloud.clickhouse.v1.ClickhouseConfig.RabbitmqR\x08rabbitmq\x1a\xab\x0c\n\tMergeTree\x12\x63\n\x1freplicated_deduplication_window\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1dreplicatedDeduplicationWindow\x12p\n\'replicated_deduplication_window_seconds\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR$replicatedDeduplicationWindowSeconds\x12N\n\x15parts_to_delay_insert\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12partsToDelayInsert\x12N\n\x15parts_to_throw_insert\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12partsToThrowInsert\x12_\n\x1einactive_parts_to_delay_insert\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1ainactivePartsToDelayInsert\x12_\n\x1einactive_parts_to_throw_insert\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1ainactivePartsToThrowInsert\x12_\n\x1emax_replicated_merges_in_queue\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1amaxReplicatedMergesInQueue\x12\x8e\x01\n9number_of_free_entries_in_pool_to_lower_max_size_of_merge\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR.numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge\x12m\n\'max_bytes_to_merge_at_min_space_in_pool\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1fmaxBytesToMergeAtMinSpaceInPool\x12m\n\'max_bytes_to_merge_at_max_space_in_pool\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1fmaxBytesToMergeAtMaxSpaceInPool\x12Q\n\x17min_bytes_for_wide_part\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13minBytesForWidePart\x12O\n\x16min_rows_for_wide_part\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12minRowsForWidePart\x12I\n\x13ttl_only_drop_parts\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10ttlOnlyDropParts\x12N\n\x16merge_with_ttl_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationR\x13mergeWithTtlTimeout\x12i\n$merge_with_recompression_ttl_timeout\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationR mergeWithRecompressionTtlTimeout\x12k\n%allow_remote_fs_zero_copy_replication\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueR allowRemoteFsZeroCopyReplication\x1a\xc3\x05\n\x05Kafka\x12o\n\x11security_protocol\x18\x01 \x01(\x0e\x32\x42.doublecloud.clickhouse.v1.ClickhouseConfig.Kafka.SecurityProtocolR\x10securityProtocol\x12\x66\n\x0esasl_mechanism\x18\x02 \x01(\x0e\x32?.doublecloud.clickhouse.v1.ClickhouseConfig.Kafka.SaslMechanismR\rsaslMechanism\x12\x41\n\rsasl_username\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0csaslUsername\x12\x41\n\rsasl_password\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0csaslPassword\"\xb3\x01\n\x10SecurityProtocol\x12\x1d\n\x19SECURITY_PROTOCOL_INVALID\x10\x00\x12\x1f\n\x1bSECURITY_PROTOCOL_PLAINTEXT\x10\x01\x12\x19\n\x15SECURITY_PROTOCOL_SSL\x10\x02\x12$\n SECURITY_PROTOCOL_SASL_PLAINTEXT\x10\x03\x12\x1e\n\x1aSECURITY_PROTOCOL_SASL_SSL\x10\x04\"\xa4\x01\n\rSaslMechanism\x12\x1a\n\x16SASL_MECHANISM_INVALID\x10\x00\x12\x19\n\x15SASL_MECHANISM_GSSAPI\x10\x01\x12\x18\n\x14SASL_MECHANISM_PLAIN\x10\x02\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_256\x10\x03\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_512\x10\x04\x1a\xb2\x01\n\x08Rabbitmq\x12\x38\n\x08username\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08username\x12\x38\n\x08password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08password\x12\x32\n\x05vhost\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05vhost\x1a\xbc\x02\n\x0b\x43ompression\x12V\n\x06method\x18\x01 \x01(\x0e\x32>.doublecloud.clickhouse.v1.ClickhouseConfig.Compression.MethodR\x06method\x12\"\n\rmin_part_size\x18\x02 \x01(\x03R\x0bminPartSize\x12-\n\x13min_part_size_ratio\x18\x03 \x01(\x01R\x10minPartSizeRatio\x12\x31\n\x05level\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x05level\"O\n\x06Method\x12\x12\n\x0eMETHOD_INVALID\x10\x00\x12\x0e\n\nMETHOD_LZ4\x10\x01\x12\x0f\n\x0bMETHOD_ZSTD\x10\x02\x12\x10\n\x0cMETHOD_LZ4HC\x10\x03\x1a\x95\x03\n\x0eGraphiteRollup\x12^\n\x08patterns\x18\x01 \x03(\x0b\x32\x42.doublecloud.clickhouse.v1.ClickhouseConfig.GraphiteRollup.PatternR\x08patterns\x1a\xa2\x02\n\x07Pattern\x12\x34\n\x06regexp\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06regexp\x12\x38\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x66unction\x12j\n\tretention\x18\x03 \x03(\x0b\x32L.doublecloud.clickhouse.v1.ClickhouseConfig.GraphiteRollup.Pattern.RetentionR\tretention\x1a;\n\tRetention\x12\x10\n\x03\x61ge\x18\x01 \x01(\x03R\x03\x61ge\x12\x1c\n\tprecision\x18\x02 \x01(\x03R\tprecision\x1a}\n\x13GraphiteRollupEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12P\n\x05value\x18\x02 \x01(\x0b\x32:.doublecloud.clickhouse.v1.ClickhouseConfig.GraphiteRollupR\x05value:\x02\x38\x01\x1aq\n\x10KafkaTopicsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x31.doublecloud.clickhouse.v1.ClickhouseConfig.KafkaR\x05value:\x02\x38\x01\"\x92\x01\n\x08LogLevel\x12\x15\n\x11LOG_LEVEL_INVALID\x10\x00\x12\x13\n\x0fLOG_LEVEL_TRACE\x10\x01\x12\x13\n\x0fLOG_LEVEL_DEBUG\x10\x02\x12\x19\n\x15LOG_LEVEL_INFORMATION\x10\x03\x12\x15\n\x11LOG_LEVEL_WARNING\x10\x04\x12\x13\n\x0fLOG_LEVEL_ERROR\x10\x05\x42\x41Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _CLICKHOUSECONFIG_GRAPHITEROLLUPENTRY._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUPENTRY._serialized_options = b'8\001'
  _CLICKHOUSECONFIG_KAFKATOPICSENTRY._options = None
  _CLICKHOUSECONFIG_KAFKATOPICSENTRY._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONFIG']._serialized_start=134
  _globals['_CLICKHOUSECONFIG']._serialized_end=5751
  _globals['_CLICKHOUSECONFIG_MERGETREE']._serialized_start=2163
  _globals['_CLICKHOUSECONFIG_MERGETREE']._serialized_end=3742
  _globals['_CLICKHOUSECONFIG_KAFKA']._serialized_start=3745
  _globals['_CLICKHOUSECONFIG_KAFKA']._serialized_end=4452
  _globals['_CLICKHOUSECONFIG_KAFKA_SECURITYPROTOCOL']._serialized_start=4106
  _globals['_CLICKHOUSECONFIG_KAFKA_SECURITYPROTOCOL']._serialized_end=4285
  _globals['_CLICKHOUSECONFIG_KAFKA_SASLMECHANISM']._serialized_start=4288
  _globals['_CLICKHOUSECONFIG_KAFKA_SASLMECHANISM']._serialized_end=4452
  _globals['_CLICKHOUSECONFIG_RABBITMQ']._serialized_start=4455
  _globals['_CLICKHOUSECONFIG_RABBITMQ']._serialized_end=4633
  _globals['_CLICKHOUSECONFIG_COMPRESSION']._serialized_start=4636
  _globals['_CLICKHOUSECONFIG_COMPRESSION']._serialized_end=4952
  _globals['_CLICKHOUSECONFIG_COMPRESSION_METHOD']._serialized_start=4873
  _globals['_CLICKHOUSECONFIG_COMPRESSION_METHOD']._serialized_end=4952
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP']._serialized_start=4955
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP']._serialized_end=5360
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN']._serialized_start=5070
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN']._serialized_end=5360
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION']._serialized_start=5301
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION']._serialized_end=5360
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUPENTRY']._serialized_start=5362
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUPENTRY']._serialized_end=5487
  _globals['_CLICKHOUSECONFIG_KAFKATOPICSENTRY']._serialized_start=5489
  _globals['_CLICKHOUSECONFIG_KAFKATOPICSENTRY']._serialized_end=5602
  _globals['_CLICKHOUSECONFIG_LOGLEVEL']._serialized_start=5605
  _globals['_CLICKHOUSECONFIG_LOGLEVEL']._serialized_end=5751
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/operation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/doublecloud/transfer/v1/operation_service.proto\x12\x17\x64oublecloud.transfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x64oublecloud/v1/operation.proto\"8\n\x13GetOperationRequest\x12!\n\x0coperation_id\x18\x01 \x01(\tR\x0boperationId2\x88\x01\n\x10OperationService\x12t\n\x03Get\x12,.doublecloud.transfer.v1.GetOperationRequest\x1a\x19.doublecloud.v1.Operation\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/operation/{operation_id}B=Z;github.com/doublecloud/api/doublecloud/transfer/v1;transferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.operation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/doublecloud/api/doublecloud/transfer/v1;transfer'
  _OPERATIONSERVICE.methods_by_name['Get']._options = None
  _OPERATIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/operation/{operation_id}'
  _globals['_GETOPERATIONREQUEST']._serialized_start=138
  _globals['_GETOPERATIONREQUEST']._serialized_end=194
  _globals['_OPERATIONSERVICE']._serialized_start=197
  _globals['_OPERATIONSERVICE']._serialized_end=333
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/mssql_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;doublecloud/transfer/v1/endpoint/airbyte/mssql_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"\xf1\x07\n\x0bMSSQLSource\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12\x1a\n\x08\x64\x61tabase\x18\x03 \x01(\tR\x08\x64\x61tabase\x12\x1a\n\x08username\x18\x04 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x05 \x01(\tR\x08password\x12{\n\x12replication_method\x18\x06 \x01(\x0e\x32L.doublecloud.transfer.v1.endpoint.airbyte.MSSQLSource.MSSQLReplicationMethodR\x11replicationMethod\x12^\n\nssl_method\x18\x07 \x01(\x0b\x32?.doublecloud.transfer.v1.endpoint.airbyte.MSSQLSource.SSLConfigR\tsslMethod\x1a\x10\n\x0eSSLUnencrypted\x1a\x15\n\x13SSLEncryptedTrusted\x1aQ\n\x16SSLEncryptedVerifyCert\x12\x37\n\x18host_name_in_certificate\x18\x01 \x01(\tR\x15hostNameInCertificate\x1a\xb1\x03\n\tSSLConfig\x12h\n\x0bunencrypted\x18\x01 \x01(\x0b\x32\x44.doublecloud.transfer.v1.endpoint.airbyte.MSSQLSource.SSLUnencryptedH\x00R\x0bunencrypted\x12\x98\x01\n\"encrypted_trust_server_certificate\x18\x02 \x01(\x0b\x32I.doublecloud.transfer.v1.endpoint.airbyte.MSSQLSource.SSLEncryptedTrustedH\x00R\x1f\x65ncryptedTrustServerCertificate\x12\x90\x01\n\x1c\x65ncrypted_verify_certificate\x18\x03 \x01(\x0b\x32L.doublecloud.transfer.v1.endpoint.airbyte.MSSQLSource.SSLEncryptedVerifyCertH\x00R\x1a\x65ncryptedVerifyCertificateB\x0c\n\nssl_method\"Y\n\x16MSSQLReplicationMethod\x12(\n$MSSQL_REPLICATION_METHOD_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x07\n\x03\x43\x44\x43\x10\x02\x42VZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.mssql_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_MSSQLSOURCE']._serialized_start=106
  _globals['_MSSQLSOURCE']._serialized_end=1115
  _globals['_MSSQLSOURCE_SSLUNENCRYPTED']._serialized_start=466
  _globals['_MSSQLSOURCE_SSLUNENCRYPTED']._serialized_end=482
  _globals['_MSSQLSOURCE_SSLENCRYPTEDTRUSTED']._serialized_start=484
  _globals['_MSSQLSOURCE_SSLENCRYPTEDTRUSTED']._serialized_end=505
  _globals['_MSSQLSOURCE_SSLENCRYPTEDVERIFYCERT']._serialized_start=507
  _globals['_MSSQLSOURCE_SSLENCRYPTEDVERIFYCERT']._serialized_end=588
  _globals['_MSSQLSOURCE_SSLCONFIG']._serialized_start=591
  _globals['_MSSQLSOURCE_SSLCONFIG']._serialized_end=1024
  _globals['_MSSQLSOURCE_MSSQLREPLICATIONMETHOD']._serialized_start=1026
  _globals['_MSSQLSOURCE_MSSQLREPLICATIONMETHOD']._serialized_end=1115
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/bigquery_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>doublecloud/transfer/v1/endpoint/airbyte/bigquery_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"y\n\x0e\x42igQuerySource\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x1d\n\ndataset_id\x18\x02 \x01(\tR\tdatasetId\x12)\n\x10\x63redentials_json\x18\x03 \x01(\tR\x0f\x63redentialsJsonBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.bigquery_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_BIGQUERYSOURCE']._serialized_start=108
  _globals['_BIGQUERYSOURCE']._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!doublecloud/kafka/v1/config.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xaa\x01\n\x0bKafkaConfig\x12G\n\x11message_max_bytes\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0fmessageMaxBytes\x12R\n\x17replica_fetch_max_bytes\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14replicaFetchMaxBytesB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_KAFKACONFIG']._serialized_start=92
  _globals['_KAFKACONFIG']._serialized_end=262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1doublecloud/transfer/v1/endpoint/clickhouse.proto\x12 doublecloud.transfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\x1a-doublecloud/transfer/v1/endpoint/common.proto\";\n\x0f\x43lickhouseShard\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05hosts\x18\x02 \x03(\tR\x05hosts\"\xe4\x01\n\x13OnPremiseClickhouse\x12I\n\x06shards\x18\x01 \x03(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.ClickhouseShardR\x06shards\x12\x1b\n\thttp_port\x18\x03 \x01(\x03R\x08httpPort\x12\x1f\n\x0bnative_port\x18\x04 \x01(\x03R\nnativePort\x12\x44\n\x08tls_mode\x18\x08 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\"\x9e\x02\n\x1b\x43lickhouseConnectionOptions\x12&\n\x0emdb_cluster_id\x18\x05 \x01(\tH\x00R\x0cmdbClusterId\x12V\n\non_premise\x18\x02 \x01(\x0b\x32\x35.doublecloud.transfer.v1.endpoint.OnPremiseClickhouseH\x00R\tonPremise\x12\x1a\n\x08\x64\x61tabase\x18\x08 \x01(\tR\x08\x64\x61tabase\x12\x12\n\x04user\x18\x06 \x01(\tR\x04user\x12\x44\n\x08password\x18\x07 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08passwordB\t\n\x07\x61\x64\x64ress\"\x94\x01\n\x14\x43lickhouseConnection\x12n\n\x12\x63onnection_options\x18\x01 \x01(\x0b\x32=.doublecloud.transfer.v1.endpoint.ClickhouseConnectionOptionsH\x00R\x11\x63onnectionOptionsB\x0c\n\nconnection\"\x9e\x05\n\x12\x43lickhouseSharding\x12r\n\x11\x63olumn_value_hash\x18\x01 \x01(\x0b\x32\x44.doublecloud.transfer.v1.endpoint.ClickhouseSharding.ColumnValueHashH\x00R\x0f\x63olumnValueHash\x12p\n\x0e\x63ustom_mapping\x18\x02 \x01(\x0b\x32G.doublecloud.transfer.v1.endpoint.ClickhouseSharding.ColumnValueMappingH\x00R\rcustomMapping\x12\x39\n\x0btransfer_id\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\ntransferId\x1a\x32\n\x0f\x43olumnValueHash\x12\x1f\n\x0b\x63olumn_name\x18\x01 \x01(\tR\ncolumnName\x1a\xa6\x02\n\x12\x43olumnValueMapping\x12\x1f\n\x0b\x63olumn_name\x18\x01 \x01(\tR\ncolumnName\x12n\n\x07mapping\x18\x02 \x03(\x0b\x32T.doublecloud.transfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShardR\x07mapping\x1a\x7f\n\x0cValueToShard\x12P\n\x0c\x63olumn_value\x18\x01 \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.ColumnValueR\x0b\x63olumnValue\x12\x1d\n\nshard_name\x18\x02 \x01(\tR\tshardNameB\n\n\x08sharding\"\xb8\x01\n\x10\x43lickhouseSource\x12V\n\nconnection\x18\x01 \x01(\x0b\x32\x36.doublecloud.transfer.v1.endpoint.ClickhouseConnectionR\nconnection\x12%\n\x0einclude_tables\x18\x07 \x03(\tR\rincludeTables\x12%\n\x0e\x65xclude_tables\x18\x08 \x03(\tR\rexcludeTables\"\x9e\x03\n\x10\x43lickhouseTarget\x12V\n\nconnection\x18\x02 \x01(\x0b\x32\x36.doublecloud.transfer.v1.endpoint.ClickhouseConnectionR\nconnection\x12\x36\n\x17\x63lickhouse_cluster_name\x18\x32 \x01(\tR\x15\x63lickhouseClusterName\x12\x46\n\talt_names\x18\x11 \x03(\x0b\x32).doublecloud.transfer.v1.endpoint.AltNameR\x08\x61ltNames\x12P\n\x08sharding\x18\x16 \x01(\x0b\x32\x34.doublecloud.transfer.v1.endpoint.ClickhouseShardingR\x08sharding\x12`\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32\x39.doublecloud.transfer.v1.endpoint.ClickhouseCleanupPolicyR\rcleanupPolicy*\xb8\x01\n\x17\x43lickhouseCleanupPolicy\x12)\n%CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_DISABLED\x10\x01\x12\"\n\x1e\x43LICKHOUSE_CLEANUP_POLICY_DROP\x10\x02\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_TRUNCATE\x10\x03\x42\x46ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.clickhouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_CLICKHOUSECLEANUPPOLICY']._serialized_start=2173
  _globals['_CLICKHOUSECLEANUPPOLICY']._serialized_end=2357
  _globals['_CLICKHOUSESHARD']._serialized_start=163
  _globals['_CLICKHOUSESHARD']._serialized_end=222
  _globals['_ONPREMISECLICKHOUSE']._serialized_start=225
  _globals['_ONPREMISECLICKHOUSE']._serialized_end=453
  _globals['_CLICKHOUSECONNECTIONOPTIONS']._serialized_start=456
  _globals['_CLICKHOUSECONNECTIONOPTIONS']._serialized_end=742
  _globals['_CLICKHOUSECONNECTION']._serialized_start=745
  _globals['_CLICKHOUSECONNECTION']._serialized_end=893
  _globals['_CLICKHOUSESHARDING']._serialized_start=896
  _globals['_CLICKHOUSESHARDING']._serialized_end=1566
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEHASH']._serialized_start=1207
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEHASH']._serialized_end=1257
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING']._serialized_start=1260
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING']._serialized_end=1554
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD']._serialized_start=1427
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD']._serialized_end=1554
  _globals['_CLICKHOUSESOURCE']._serialized_start=1569
  _globals['_CLICKHOUSESOURCE']._serialized_end=1753
  _globals['_CLICKHOUSETARGET']._serialized_start=1756
  _globals['_CLICKHOUSETARGET']._serialized_end=2170
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/v1/operation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64oublecloud/v1/operation.proto\x12\x0e\x64oublecloud.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\x8e\x05\n\tOperation\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\ncreated_by\x18\x04 \x01(\tR\tcreatedBy\x12\x43\n\x08metadata\x18\x05 \x03(\x0b\x32\'.doublecloud.v1.Operation.MetadataEntryR\x08metadata\x12;\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12\x39\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12;\n\x0b\x66inish_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nfinishTime\x12\x38\n\x06status\x18\t \x01(\x0e\x32 .doublecloud.v1.Operation.StatusR\x06status\x12(\n\x05\x65rror\x18\n \x01(\x0b\x32\x12.google.rpc.StatusR\x05\x65rror\x12\x1f\n\x0bresource_id\x18\x0b \x01(\tR\nresourceId\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"U\n\x06Status\x12\x12\n\x0eSTATUS_INVALID\x10\x00\x12\x12\n\x0eSTATUS_PENDING\x10\x01\x12\x12\n\x0eSTATUS_RUNNING\x10\x02\x12\x0f\n\x0bSTATUS_DONE\x10\x03\x42\x37Z5github.com/doublecloud/api/doublecloud/v1;doublecloudb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.v1.operation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/v1;doublecloud'
  _OPERATION_METADATAENTRY._options = None
  _OPERATION_METADATAENTRY._serialized_options = b'8\001'
  _globals['_OPERATION']._serialized_start=109
  _globals['_OPERATION']._serialized_end=763
  _globals['_OPERATION_METADATAENTRY']._serialized_start=617
  _globals['_OPERATION_METADATAENTRY']._serialized_end=676
  _globals['_OPERATION_STATUS']._serialized_start=678
  _globals['_OPERATION_STATUS']._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/mysql.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,doublecloud/transfer/v1/endpoint/mysql.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\"\x80\x01\n\x0eOnPremiseMysql\x12\x14\n\x05hosts\x18\x05 \x03(\tR\x05hosts\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12\x44\n\x08tls_mode\x18\x06 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\"r\n\x0fMysqlConnection\x12Q\n\non_premise\x18\x02 \x01(\x0b\x32\x30.doublecloud.transfer.v1.endpoint.OnPremiseMysqlH\x00R\tonPremiseB\x0c\n\nconnection\"\xd9\x02\n\x1bMysqlObjectTransferSettings\x12I\n\x04view\x18\x01 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04view\x12O\n\x07routine\x18\x02 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x07routine\x12O\n\x07trigger\x18\x03 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x07trigger\x12M\n\x06tables\x18\x04 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x06tables\"\xfa\x03\n\x0bMysqlSource\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MysqlConnectionR\nconnection\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12)\n\x10service_database\x18\x0f \x01(\tR\x0fserviceDatabase\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12\x30\n\x14include_tables_regex\x18\x0c \x03(\tR\x12includeTablesRegex\x12\x30\n\x14\x65xclude_tables_regex\x18\r \x03(\tR\x12\x65xcludeTablesRegex\x12\x1a\n\x08timezone\x18\x08 \x01(\tR\x08timezone\x12w\n\x18object_transfer_settings\x18\x0b \x01(\x0b\x32=.doublecloud.transfer.v1.endpoint.MysqlObjectTransferSettingsR\x16objectTransferSettings\"\xef\x03\n\x0bMysqlTarget\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MysqlConnectionR\nconnection\x12\'\n\x0fsecurity_groups\x18\x10 \x03(\tR\x0esecurityGroups\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12\x19\n\x08sql_mode\x18\x05 \x01(\tR\x07sqlMode\x12\x34\n\x16skip_constraint_checks\x18\x06 \x01(\x08R\x14skipConstraintChecks\x12\x1a\n\x08timezone\x18\x07 \x01(\tR\x08timezone\x12V\n\x0e\x63leanup_policy\x18\x08 \x01(\x0e\x32/.doublecloud.transfer.v1.endpoint.CleanupPolicyR\rcleanupPolicy\x12)\n\x10service_database\x18\x0f \x01(\tR\x0fserviceDatabaseBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.mysql_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_ONPREMISEMYSQL']._serialized_start=130
  _globals['_ONPREMISEMYSQL']._serialized_end=258
  _globals['_MYSQLCONNECTION']._serialized_start=260
  _globals['_MYSQLCONNECTION']._serialized_end=374
  _globals['_MYSQLOBJECTTRANSFERSETTINGS']._serialized_start=377
  _globals['_MYSQLOBJECTTRANSFERSETTINGS']._serialized_end=722
  _globals['_MYSQLSOURCE']._serialized_start=725
  _globals['_MYSQLSOURCE']._serialized_end=1231
  _globals['_MYSQLTARGET']._serialized_start=1234
  _globals['_MYSQLTARGET']._serialized_end=1729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from doublecloud.v1 import cluster_pb2 as doublecloud_dot_v1_dot_cluster__pb2
from doublecloud.v1 import maintenance_pb2 as doublecloud_dot_v1_dot_maintenance__pb2
from doublecloud.kafka.v1 import config_pb2 as doublecloud_dot_kafka_dot_v1_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"doublecloud/kafka/v1/cluster.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1c\x64oublecloud/v1/cluster.proto\x1a doublecloud/v1/maintenance.proto\x1a!doublecloud/kafka/v1/config.proto\"\xac\x07\n\x07\x43luster\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x03 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x04 \x01(\tR\x08regionId\x12;\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12\x35\n\x06status\x18\x08 \x01(\x0e\x32\x1d.doublecloud.v1.ClusterStatusR\x06status\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12\x44\n\tresources\x18\n \x01(\x0b\x32&.doublecloud.kafka.v1.ClusterResourcesR\tresources\x12M\n\x0f\x63onnection_info\x18\x0b \x01(\x0b\x32$.doublecloud.kafka.v1.ConnectionInfoR\x0e\x63onnectionInfo\x12.\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12>\n\nencryption\x18\r \x01(\x0b\x32\x1e.doublecloud.v1.DataEncryptionR\nencryption\x12\x1d\n\nnetwork_id\x18\x0e \x01(\tR\tnetworkId\x12\x63\n\x17private_connection_info\x18\x0f \x01(\x0b\x32+.doublecloud.kafka.v1.PrivateConnectionInfoR\x15privateConnectionInfo\x12P\n\x12maintenance_window\x18\x10 \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12Q\n\x11planned_operation\x18\x11 \x01(\x0b\x32$.doublecloud.v1.MaintenanceOperationR\x10plannedOperation\x12\x44\n\x0ckafka_config\x18\x12 \x01(\x0b\x32!.doublecloud.kafka.v1.KafkaConfigR\x0bkafkaConfig\"\xc4\x02\n\x10\x43lusterResources\x12\x42\n\x05kafka\x18\x01 \x01(\x0b\x32,.doublecloud.kafka.v1.ClusterResources.KafkaR\x05kafka\x1a\xeb\x01\n\x05Kafka\x12,\n\x12resource_preset_id\x18\x01 \x01(\tR\x10resourcePresetId\x12\x38\n\tdisk_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x08\x64iskSize\x12>\n\x0c\x62roker_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0b\x62rokerCount\x12:\n\nzone_count\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\tzoneCount\"m\n\x0e\x43onnectionInfo\x12+\n\x11\x63onnection_string\x18\x01 \x01(\tR\x10\x63onnectionString\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"t\n\x15PrivateConnectionInfo\x12+\n\x11\x63onnection_string\x18\x01 \x01(\tR\x10\x63onnectionString\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"m\n\x04Host\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\x1a.doublecloud.v1.HostStatusR\x06statusB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_CLUSTER']._serialized_start=225
  _globals['_CLUSTER']._serialized_end=1165
  _globals['_CLUSTERRESOURCES']._serialized_start=1168
  _globals['_CLUSTERRESOURCES']._serialized_end=1492
  _globals['_CLUSTERRESOURCES_KAFKA']._serialized_start=1257
  _globals['_CLUSTERRESOURCES_KAFKA']._serialized_end=1492
  _globals['_CONNECTIONINFO']._serialized_start=1494
  _globals['_CONNECTIONINFO']._serialized_end=1603
  _globals['_PRIVATECONNECTIONINFO']._serialized_start=1605
  _globals['_PRIVATECONNECTIONINFO']._serialized_end=1721
  _globals['_HOST']._serialized_start=1723
  _globals['_HOST']._serialized_end=1832
# @@protoc_insertion_point(module_scope)



import inspect

import grpc

from doublecloud import _channels, _operation_waiter
from doublecloud._backoff import backoff_exponential_with_jitter
from doublecloud._retry_interceptor import RetryInterceptor
from doublecloud._wrappers import Wrappers


class SDK(object):
    def __init__(self, interceptor=None, user_agent=None, **kwargs):
        """
        API entry-point object.

        :param interceptor: GRPC interceptor to be used instead of default RetryInterceptor
        :type interceptor: Union[
            UnaryUnaryClientInterceptor,
            UnaryStreamClientInterceptor,
            StreamUnaryClientInterceptor,
            StreamStreamClientInterceptor
        ]
        :param user_agent: String to prepend User-Agent metadata header for all GRPC requests made via SDK object
        :type user_agent: Optional[str]
        """
        self._channels = _channels.Channels(client_user_agent=user_agent, **kwargs)
        if interceptor is None:
            interceptor = RetryInterceptor(
                max_retry_count=5,
                per_call_timeout=30,
                back_off_func=backoff_exponential_with_jitter(1, 30),
            )
        self._default_interceptor = interceptor
        self.wrappers = Wrappers(self)

    def set_interceptor(self, interceptor):
        self._default_interceptor = interceptor

    def client(self, stub_ctor, interceptor=None):
        service = _service_for_ctor(stub_ctor)
        channel = self._channels.channel(service)
        if interceptor is not None:
            channel = grpc.intercept_channel(channel, interceptor)
        elif self._default_interceptor is not None:
            channel = grpc.intercept_channel(channel, self._default_interceptor)
        return stub_ctor(channel)

    def waiter(self, operation_id, timeout=None):
        return _operation_waiter.operation_waiter(self, operation_id, timeout)

    def wait_operation_and_get_result(self, operation, meta_type=None, timeout=None, logger=None):
        return _operation_waiter.get_operation_result(self, operation, meta_type, timeout, logger)

    def create_operation_and_get_result(
        self,
        request,
        service,
        method_name,
        meta_type=None,
        timeout=None,
        logger=None,
    ):
        operation = getattr(self.client(service), method_name)(request)
        return self.wait_operation_and_get_result(
            operation,
            meta_type=meta_type,
            timeout=timeout,
            logger=logger,
        )


def _service_for_ctor(stub_ctor):
    m = inspect.getmodule(stub_ctor)
    name = m.__name__
    if not name.startswith("doublecloud"):
        raise RuntimeError(f"Not a double.cloud service {stub_ctor}")

    for k, v in _supported_modules:
        if name.startswith(k):
            return v

    raise RuntimeError(f"Unknown service {stub_ctor}")


_supported_modules = [
    ("doublecloud.kafka", "kafka"),
    ("doublecloud.clickhouse", "clickhouse"),
    ("doublecloud.network", "network"),
    ("doublecloud.transfer", "transfer"),
    ("doublecloud.visualization", "visualization"),
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/facebook_marketing_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHdoublecloud/transfer/v1/endpoint/airbyte/facebook_marketing_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"\x9d\'\n\x17\x46\x61\x63\x65\x62ookMarketingSource\x12\x1d\n\nstart_date\x18\x01 \x01(\tR\tstartDate\x12\x1d\n\naccount_id\x18\x03 \x01(\tR\taccountId\x12\x19\n\x08\x65nd_date\x18\x02 \x01(\tR\x07\x65ndDate\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\'\n\x0finclude_deleted\x18\x05 \x01(\x08R\x0eincludeDeleted\x12\x34\n\x16\x66\x65tch_thumbnail_images\x18\x06 \x01(\x08R\x14\x66\x65tchThumbnailImages\x12x\n\x0f\x63ustom_insights\x18\x07 \x03(\x0b\x32O.doublecloud.transfer.v1.endpoint.airbyte.FacebookMarketingSource.InsightConfigR\x0e\x63ustomInsights\x1a\xf1\x02\n\rInsightConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12_\n\x06\x66ields\x18\x02 \x03(\x0e\x32G.doublecloud.transfer.v1.endpoint.airbyte.FacebookMarketingSource.FieldR\x06\x66ields\x12k\n\nbreakdowns\x18\x03 \x03(\x0e\x32K.doublecloud.transfer.v1.endpoint.airbyte.FacebookMarketingSource.BreakdownR\nbreakdowns\x12~\n\x11\x61\x63tion_breakdowns\x18\x04 \x03(\x0e\x32Q.doublecloud.transfer.v1.endpoint.airbyte.FacebookMarketingSource.ActionBreakdownR\x10\x61\x63tionBreakdowns\"\xf3\x1a\n\x05\x46ield\x12\x15\n\x11\x46IELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43\x43OUNT_CURRENCY\x10\x01\x12\x0e\n\nACCOUNT_ID\x10\x02\x12\x10\n\x0c\x41\x43\x43OUNT_NAME\x10\x03\x12\x11\n\rACTION_VALUES\x10\x04\x12\x0b\n\x07\x41\x43TIONS\x10\x05\x12\x10\n\x0c\x41\x44_BID_VALUE\x10\x06\x12\x14\n\x10\x41\x44_CLICK_ACTIONS\x10\x07\x12\t\n\x05\x41\x44_ID\x10\x08\x12\x19\n\x15\x41\x44_IMPRESSION_ACTIONS\x10\t\x12\x0b\n\x07\x41\x44_NAME\x10\n\x12\x13\n\x0f\x41\x44SET_BID_VALUE\x10\x0b\x12\r\n\tADSET_END\x10\x0c\x12\x0c\n\x08\x41\x44SET_ID\x10\r\x12\x0e\n\nADSET_NAME\x10\x0e\x12\x0f\n\x0b\x41\x44SET_START\x10\x0f\x12\x11\n\rAGE_TARGETING\x10\x10\x12\x17\n\x13\x41TTRIBUTION_SETTING\x10\x11\x12\x0f\n\x0b\x41UCTION_BID\x10\x12\x12\x1b\n\x17\x41UCTION_COMPETITIVENESS\x10\x13\x12\x1e\n\x1a\x41UCTION_MAX_COMPETITOR_BID\x10\x14\x12\x0f\n\x0b\x42UYING_TYPE\x10\x15\x12\x0f\n\x0b\x43\x41MPAIGN_ID\x10\x16\x12\x11\n\rCAMPAIGN_NAME\x10\x17\x12\x1b\n\x17\x43\x41NVAS_AVG_VIEW_PERCENT\x10\x18\x12\x18\n\x14\x43\x41NVAS_AVG_VIEW_TIME\x10\x19\x12\x1b\n\x17\x43\x41TALOG_SEGMENT_ACTIONS\x10\x1a\x12\x19\n\x15\x43\x41TALOG_SEGMENT_VALUE\x10\x1b\x12.\n*CATALOG_SEGMENT_VALUE_MOBILE_PURCHASE_ROAS\x10\x1c\x12,\n(CATALOG_SEGMENT_VALUE_OMNI_PURCHASE_ROAS\x10\x1d\x12/\n+CATALOG_SEGMENT_VALUE_WEBSITE_PURCHASE_ROAS\x10\x1e\x12\n\n\x06\x43LICKS\x10\x1f\x12\x1b\n\x17\x43ONVERSION_RATE_RANKING\x10 \x12\x15\n\x11\x43ONVERSION_VALUES\x10!\x12\x0f\n\x0b\x43ONVERSIONS\x10\"\x12\x1e\n\x1a\x43ONVERTED_PRODUCT_QUANTITY\x10#\x12\x1b\n\x17\x43ONVERTED_PRODUCT_VALUE\x10$\x12\x1e\n\x1a\x43OST_PER_15_SEC_VIDEO_VIEW\x10%\x12(\n$COST_PER_2_SEC_CONTINUOUS_VIDEO_VIEW\x10&\x12\x18\n\x14\x43OST_PER_ACTION_TYPE\x10\'\x12\x15\n\x11\x43OST_PER_AD_CLICK\x10(\x12\x17\n\x13\x43OST_PER_CONVERSION\x10)\x12\x1e\n\x1a\x43OST_PER_DDA_COUNTBY_CONVS\x10*\x12#\n\x1f\x43OST_PER_ESTIMATED_AD_RECALLERS\x10+\x12\x1e\n\x1a\x43OST_PER_INLINE_LINK_CLICK\x10,\x12#\n\x1f\x43OST_PER_INLINE_POST_ENGAGEMENT\x10-\x12\'\n#COST_PER_ONE_THOUSAND_AD_IMPRESSION\x10.\x12\x1b\n\x17\x43OST_PER_OUTBOUND_CLICK\x10/\x12\x15\n\x11\x43OST_PER_THRUPLAY\x10\x30\x12\x1f\n\x1b\x43OST_PER_UNIQUE_ACTION_TYPE\x10\x31\x12\x19\n\x15\x43OST_PER_UNIQUE_CLICK\x10\x32\x12\x1e\n\x1a\x43OST_PER_UNIQUE_CONVERSION\x10\x33\x12%\n!COST_PER_UNIQUE_INLINE_LINK_CLICK\x10\x34\x12\"\n\x1e\x43OST_PER_UNIQUE_OUTBOUND_CLICK\x10\x35\x12\x07\n\x03\x43PC\x10\x36\x12\x07\n\x03\x43PM\x10\x37\x12\x07\n\x03\x43PP\x10\x38\x12\x10\n\x0c\x43REATED_TIME\x10\x39\x12\x07\n\x03\x43TR\x10:\x12\x0e\n\nDATE_START\x10;\x12\r\n\tDATE_STOP\x10<\x12\x15\n\x11\x44\x44\x41_COUNTBY_CONVS\x10=\x12\x0f\n\x0b\x44\x44\x41_RESULTS\x10>\x12\x1b\n\x17\x45NGAGEMENT_RATE_RANKING\x10?\x12\x1c\n\x18\x45STIMATED_AD_RECALL_RATE\x10@\x12(\n$ESTIMATED_AD_RECALL_RATE_LOWER_BOUND\x10\x41\x12(\n$ESTIMATED_AD_RECALL_RATE_UPPER_BOUND\x10\x42\x12\x1a\n\x16\x45STIMATED_AD_RECALLERS\x10\x43\x12&\n\"ESTIMATED_AD_RECALLERS_LOWER_BOUND\x10\x44\x12&\n\"ESTIMATED_AD_RECALLERS_UPPER_BOUND\x10\x45\x12\r\n\tFREQUENCY\x10\x46\x12\x19\n\x15\x46ULL_VIEW_IMPRESSIONS\x10G\x12\x13\n\x0f\x46ULL_VIEW_REACH\x10H\x12\x14\n\x10GENDER_TARGETING\x10I\x12\x0f\n\x0bIMPRESSIONS\x10J\x12\x19\n\x15INLINE_LINK_CLICK_CTR\x10K\x12\x16\n\x12INLINE_LINK_CLICKS\x10L\x12\x1a\n\x16INLINE_POST_ENGAGEMENT\x10M\x12%\n!INSTANT_EXPERIENCE_CLICKS_TO_OPEN\x10N\x12&\n\"INSTANT_EXPERIENCE_CLICKS_TO_START\x10O\x12&\n\"INSTANT_EXPERIENCE_OUTBOUND_CLICKS\x10P\x12\x1d\n\x19INTERACTIVE_COMPONENT_TAP\x10Q\x12\n\n\x06LABELS\x10R\x12\x0c\n\x08LOCATION\x10S\x12\x1c\n\x18MOBILE_APP_PURCHASE_ROAS\x10T\x12\r\n\tOBJECTIVE\x10U\x12\x15\n\x11OPTIMIZATION_GOAL\x10V\x12\x13\n\x0fOUTBOUND_CLICKS\x10W\x12\x17\n\x13OUTBOUND_CLICKS_CTR\x10X\x12\x13\n\x0fPLACE_PAGE_NAME\x10Y\x12\x11\n\rPURCHASE_ROAS\x10Z\x12+\n\'QUALIFYING_QUESTION_QUALIFY_ANSWER_RATE\x10[\x12\x13\n\x0fQUALITY_RANKING\x10\\\x12\x16\n\x12QUALITY_SCORE_ECTR\x10]\x12\x16\n\x12QUALITY_SCORE_ECVR\x10^\x12\x19\n\x15QUALITY_SCORE_ORGANIC\x10_\x12\t\n\x05REACH\x10`\x12\x10\n\x0cSOCIAL_SPEND\x10\x61\x12\t\n\x05SPEND\x10\x62\x12\x13\n\x0fTOTAL_POSTBACKS\x10\x63\x12\x12\n\x0eUNIQUE_ACTIONS\x10\x64\x12\x11\n\rUNIQUE_CLICKS\x10\x65\x12\x16\n\x12UNIQUE_CONVERSIONS\x10\x66\x12\x0e\n\nUNIQUE_CTR\x10g\x12 \n\x1cUNIQUE_INLINE_LINK_CLICK_CTR\x10h\x12\x1d\n\x19UNIQUE_INLINE_LINK_CLICKS\x10i\x12\x1a\n\x16UNIQUE_LINK_CLICKS_CTR\x10j\x12\x1a\n\x16UNIQUE_OUTBOUND_CLICKS\x10k\x12\x1e\n\x1aUNIQUE_OUTBOUND_CLICKS_CTR\x10l\x12\x31\n-UNIQUE_VIDEO_CONTINUOUS_2_SEC_WATCHED_ACTIONS\x10m\x12\x1c\n\x18UNIQUE_VIDEO_VIEW_15_SEC\x10n\x12\x10\n\x0cUPDATED_TIME\x10o\x12 \n\x1cVIDEO_15_SEC_WATCHED_ACTIONS\x10p\x12 \n\x1cVIDEO_30_SEC_WATCHED_ACTIONS\x10q\x12\"\n\x1eVIDEO_AVG_TIME_WATCHED_ACTIONS\x10r\x12*\n&VIDEO_CONTINUOUS_2_SEC_WATCHED_ACTIONS\x10s\x12\x1e\n\x1aVIDEO_P100_WATCHED_ACTIONS\x10t\x12\x1d\n\x19VIDEO_P25_WATCHED_ACTIONS\x10u\x12\x1d\n\x19VIDEO_P50_WATCHED_ACTIONS\x10v\x12\x1d\n\x19VIDEO_P75_WATCHED_ACTIONS\x10w\x12\x1d\n\x19VIDEO_P95_WATCHED_ACTIONS\x10x\x12\x16\n\x12VIDEO_PLAY_ACTIONS\x10y\x12\x1c\n\x18VIDEO_PLAY_CURVE_ACTIONS\x10z\x12)\n%VIDEO_PLAY_RETENTION_0_TO_15S_ACTIONS\x10{\x12*\n&VIDEO_PLAY_RETENTION_20_TO_60S_ACTIONS\x10|\x12&\n\"VIDEO_PLAY_RETENTION_GRAPH_ACTIONS\x10}\x12\"\n\x1eVIDEO_THRUPLAY_WATCHED_ACTIONS\x10~\x12\x1e\n\x1aVIDEO_TIME_WATCHED_ACTIONS\x10\x7f\x12\x10\n\x0bWEBSITE_CTR\x10\x80\x01\x12\x1a\n\x15WEBSITE_PURCHASE_ROAS\x10\x82\x01\x12\r\n\x08WISH_BID\x10\x83\x01\"\x98\x04\n\tBreakdown\x12\x19\n\x15\x42REAKDOWN_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x41\x44_FORMAT_ASSET\x10\x01\x12\x07\n\x03\x41GE\x10\x02\x12\n\n\x06\x41PP_ID\x10\x03\x12\x0e\n\nBODY_ASSET\x10\x04\x12\x18\n\x14\x43\x41LL_TO_ACTION_ASSET\x10\x05\x12\x0b\n\x07\x43OUNTRY\x10\x06\x12\x15\n\x11\x44\x45SCRIPTION_ASSET\x10\x07\x12\x13\n\x0f\x44\x45VICE_PLATFORM\x10\x08\x12\x07\n\x03\x44MA\x10\t\x12\x13\n\x0f\x46REQUENCY_VALUE\x10\n\x12\n\n\x06GENDER\x10\x0b\x12\x33\n/HOURLY_STATS_AGGREGATED_BY_ADVERTISER_TIME_ZONE\x10\x0c\x12\x31\n-HOURLY_STATS_AGGREGATED_BY_AUDIENCE_TIME_ZONE\x10\r\x12\x0f\n\x0bIMAGE_ASSET\x10\x0e\x12\x15\n\x11IMPRESSION_DEVICE\x10\x0f\x12\x12\n\x0eLINK_URL_ASSET\x10\x10\x12\x11\n\rPLACE_PAGE_ID\x10\x11\x12\x15\n\x11PLATFORM_POSITION\x10\x12\x12\x0e\n\nPRODUCT_ID\x10\x13\x12\x16\n\x12PUBLISHER_PLATFORM\x10\x14\x12\n\n\x06REGION\x10\x15\x12\x16\n\x12SKAN_CONVERSION_ID\x10\x16\x12\x0f\n\x0bTITLE_ASSET\x10\x17\x12\x0e\n\nVIDEO_ASSE\x10\x18\"\xa7\x02\n\x0f\x41\x63tionBreakdown\x12 \n\x1c\x41\x43TION_BREAKDOWN_UNSPECIFIED\x10\x00\x12 \n\x1c\x41\x43TION_CANVAS_COMPONENT_NAME\x10\x01\x12\x1b\n\x17\x41\x43TION_CAROUSEL_CARD_ID\x10\x02\x12\x1d\n\x19\x41\x43TION_CAROUSEL_CARD_NAME\x10\x03\x12\x16\n\x12\x41\x43TION_DESTINATION\x10\x04\x12\x11\n\rACTION_DEVICE\x10\x05\x12\x13\n\x0f\x41\x43TION_REACTION\x10\x06\x12\x14\n\x10\x41\x43TION_TARGET_ID\x10\x07\x12\x0f\n\x0b\x41\x43TION_TYPE\x10\x08\x12\x16\n\x12\x41\x43TION_VIDEO_SOUND\x10\t\x12\x15\n\x11\x41\x43TION_VIDEO_TYPE\x10\nBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.facebook_marketing_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_FACEBOOKMARKETINGSOURCE']._serialized_start=119
  _globals['_FACEBOOKMARKETINGSOURCE']._serialized_end=5140
  _globals['_FACEBOOKMARKETINGSOURCE_INSIGHTCONFIG']._serialized_start=488
  _globals['_FACEBOOKMARKETINGSOURCE_INSIGHTCONFIG']._serialized_end=857
  _globals['_FACEBOOKMARKETINGSOURCE_FIELD']._serialized_start=860
  _globals['_FACEBOOKMARKETINGSOURCE_FIELD']._serialized_end=4303
  _globals['_FACEBOOKMARKETINGSOURCE_BREAKDOWN']._serialized_start=4306
  _globals['_FACEBOOKMARKETINGSOURCE_BREAKDOWN']._serialized_end=4842
  _globals['_FACEBOOKMARKETINGSOURCE_ACTIONBREAKDOWN']._serialized_start=4845
  _globals['_FACEBOOKMARKETINGSOURCE_ACTIONBREAKDOWN']._serialized_end=5140
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/transfer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from doublecloud.transfer.v1 import transfer_pb2 as doublecloud_dot_transfer_dot_v1_dot_transfer__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.doublecloud/transfer/v1/transfer_service.proto\x12\x17\x64oublecloud.transfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&doublecloud/transfer/v1/transfer.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"\xf0\x02\n\x15\x43reateTransferRequest\x12\x1b\n\tsource_id\x18\x01 \x01(\tR\x08sourceId\x12\x1b\n\ttarget_id\x18\x02 \x01(\tR\x08targetId\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12R\n\x06labels\x18\x08 \x03(\x0b\x32:.doublecloud.transfer.v1.CreateTransferRequest.LabelsEntryR\x06labels\x12\x1d\n\nproject_id\x18\x04 \x01(\tR\tprojectId\x12\x39\n\x04type\x18\x06 \x01(\x0e\x32%.doublecloud.transfer.v1.TransferTypeR\x04type\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xfd\x01\n\x15UpdateTransferRequest\x12\x1f\n\x0btransfer_id\x18\x01 \x01(\tR\ntransferId\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12R\n\x06labels\x18\x06 \x03(\x0b\x32:.doublecloud.transfer.v1.UpdateTransferRequest.LabelsEntryR\x06labels\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"8\n\x15\x44\x65leteTransferRequest\x12\x1f\n\x0btransfer_id\x18\x01 \x01(\tR\ntransferId\"a\n\x14ListTransfersRequest\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12*\n\x04page\x18\x03 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x04page\"\x80\x01\n\x15ListTransfersResponse\x12?\n\ttransfers\x18\x01 \x03(\x0b\x32!.doublecloud.transfer.v1.TransferR\ttransfers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"5\n\x12GetTransferRequest\x12\x1f\n\x0btransfer_id\x18\x01 \x01(\tR\ntransferId\"<\n\x19\x44\x65\x61\x63tivateTransferRequest\x12\x1f\n\x0btransfer_id\x18\x01 \x01(\tR\ntransferId\":\n\x17\x41\x63tivateTransferRequest\x12\x1f\n\x0btransfer_id\x18\x01 \x01(\tR\ntransferId2\x9a\x07\n\x0fTransferService\x12l\n\x06\x43reate\x12..doublecloud.transfer.v1.CreateTransferRequest\x1a\x19.doublecloud.v1.Operation\"\x17\x82\xd3\xe4\x93\x02\x11:\x01*\"\x0c/v1/transfer\x12z\n\x06Update\x12..doublecloud.transfer.v1.UpdateTransferRequest\x1a\x19.doublecloud.v1.Operation\"%\x82\xd3\xe4\x93\x02\x1f:\x01*2\x1a/v1/transfer/{transfer_id}\x12w\n\x06\x44\x65lete\x12..doublecloud.transfer.v1.DeleteTransferRequest\x1a\x19.doublecloud.v1.Operation\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/transfer/{transfer_id}\x12\x8e\x01\n\x04List\x12-.doublecloud.transfer.v1.ListTransfersRequest\x1a..doublecloud.transfer.v1.ListTransfersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/transfers/list/{project_id}\x12y\n\x03Get\x12+.doublecloud.transfer.v1.GetTransferRequest\x1a!.doublecloud.transfer.v1.Transfer\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/transfer/{transfer_id}\x12\x8d\x01\n\nDeactivate\x12\x32.doublecloud.transfer.v1.DeactivateTransferRequest\x1a\x19.doublecloud.v1.Operation\"0\x82\xd3\xe4\x93\x02*:\x01*\"%/v1/transfer/{transfer_id}:deactivate\x12\x87\x01\n\x08\x41\x63tivate\x12\x30.doublecloud.transfer.v1.ActivateTransferRequest\x1a\x19.doublecloud.v1.Operation\".\x82\xd3\xe4\x93\x02(:\x01*\"#/v1/transfer/{transfer_id}:activateB=Z;github.com/doublecloud/api/doublecloud/transfer/v1;transferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.transfer_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/doublecloud/api/doublecloud/transfer/v1;transfer'
  _CREATETRANSFERREQUEST_LABELSENTRY._options = None
  _CREATETRANSFERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATETRANSFERREQUEST_LABELSENTRY._options = None
  _UPDATETRANSFERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TRANSFERSERVICE.methods_by_name['Create']._options = None
  _TRANSFERSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\021:\001*\"\014/v1/transfer'
  _TRANSFERSERVICE.methods_by_name['Update']._options = None
  _TRANSFERSERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\037:\001*2\032/v1/transfer/{transfer_id}'
  _TRANSFERSERVICE.methods_by_name['Delete']._options = None
  _TRANSFERSERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\034*\032/v1/transfer/{transfer_id}'
  _TRANSFERSERVICE.methods_by_name['List']._options = None
  _TRANSFERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/v1/transfers/list/{project_id}'
  _TRANSFERSERVICE.methods_by_name['Get']._options = None
  _TRANSFERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/transfer/{transfer_id}'
  _TRANSFERSERVICE.methods_by_name['Deactivate']._options = None
  _TRANSFERSERVICE.methods_by_name['Deactivate']._serialized_options = b'\202\323\344\223\002*:\001*\"%/v1/transfer/{transfer_id}:deactivate'
  _TRANSFERSERVICE.methods_by_name['Activate']._options = None
  _TRANSFERSERVICE.methods_by_name['Activate']._serialized_options = b'\202\323\344\223\002(:\001*\"#/v1/transfer/{transfer_id}:activate'
  _globals['_CREATETRANSFERREQUEST']._serialized_start=241
  _globals['_CREATETRANSFERREQUEST']._serialized_end=609
  _globals['_CREATETRANSFERREQUEST_LABELSENTRY']._serialized_start=552
  _globals['_CREATETRANSFERREQUEST_LABELSENTRY']._serialized_end=609
  _globals['_UPDATETRANSFERREQUEST']._serialized_start=612
  _globals['_UPDATETRANSFERREQUEST']._serialized_end=865
  _globals['_UPDATETRANSFERREQUEST_LABELSENTRY']._serialized_start=552
  _globals['_UPDATETRANSFERREQUEST_LABELSENTRY']._serialized_end=609
  _globals['_DELETETRANSFERREQUEST']._serialized_start=867
  _globals['_DELETETRANSFERREQUEST']._serialized_end=923
  _globals['_LISTTRANSFERSREQUEST']._serialized_start=925
  _globals['_LISTTRANSFERSREQUEST']._serialized_end=1022
  _globals['_LISTTRANSFERSRESPONSE']._serialized_start=1025
  _globals['_LISTTRANSFERSRESPONSE']._serialized_end=1153
  _globals['_GETTRANSFERREQUEST']._serialized_start=1155
  _globals['_GETTRANSFERREQUEST']._serialized_end=1208
  _globals['_DEACTIVATETRANSFERREQUEST']._serialized_start=1210
  _globals['_DEACTIVATETRANSFERREQUEST']._serialized_end=1270
  _globals['_ACTIVATETRANSFERREQUEST']._serialized_start=1272
  _globals['_ACTIVATETRANSFERREQUEST']._serialized_end=1330
  _globals['_TRANSFERSERVICE']._serialized_start=1333
  _globals['_TRANSFERSERVICE']._serialized_end=2255
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/v1/maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n doublecloud/v1/maintenance.proto\x12\x0e\x64oublecloud.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/dayofweek.proto\"\xca\x01\n\x11MaintenanceWindow\x12\x44\n\x07\x61nytime\x18\x01 \x01(\x0b\x32(.doublecloud.v1.AnytimeMaintenanceWindowH\x00R\x07\x61nytime\x12\x65\n\x19weekly_maintenance_window\x18\x02 \x01(\x0b\x32\'.doublecloud.v1.WeeklyMaintenanceWindowH\x00R\x17weeklyMaintenanceWindowB\x08\n\x06policy\"\x1a\n\x18\x41nytimeMaintenanceWindow\"W\n\x17WeeklyMaintenanceWindow\x12(\n\x03\x64\x61y\x18\x01 \x01(\x0e\x32\x16.google.type.DayOfWeekR\x03\x64\x61y\x12\x12\n\x04hour\x18\x02 \x01(\x03R\x04hour\"\xb9\x02\n\x14MaintenanceOperation\x12\x12\n\x04info\x18\x01 \x01(\tR\x04info\x12X\n\x1ascheduled_maintenance_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x18scheduledMaintenanceTime\x12V\n\x19\x64\x65\x61\x64line_maintenance_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17\x64\x65\x61\x64lineMaintenanceTime\x12[\n\x1cnext_maintenance_window_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x19nextMaintenanceWindowTime*\x9a\x01\n\x0eRescheduleType\x12\x1b\n\x17RESCHEDULE_TYPE_INVALID\x10\x00\x12\x1d\n\x19RESCHEDULE_TYPE_IMMEDIATE\x10\x01\x12)\n%RESCHEDULE_TYPE_NEXT_AVAILABLE_WINDOW\x10\x02\x12!\n\x1dRESCHEDULE_TYPE_SPECIFIC_TIME\x10\x03\x42\x37Z5github.com/doublecloud/api/doublecloud/v1;doublecloudb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.v1.maintenance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/v1;doublecloud'
  _globals['_RESCHEDULETYPE']._serialized_start=753
  _globals['_RESCHEDULETYPE']._serialized_end=907
  _globals['_MAINTENANCEWINDOW']._serialized_start=115
  _globals['_MAINTENANCEWINDOW']._serialized_end=317
  _globals['_ANYTIMEMAINTENANCEWINDOW']._serialized_start=319
  _globals['_ANYTIMEMAINTENANCEWINDOW']._serialized_end=345
  _globals['_WEEKLYMAINTENANCEWINDOW']._serialized_start=347
  _globals['_WEEKLYMAINTENANCEWINDOW']._serialized_end=434
  _globals['_MAINTENANCEOPERATION']._serialized_start=437
  _globals['_MAINTENANCEOPERATION']._serialized_end=750
# @@protoc_insertion_point(module_scope)



import logging
import time
import uuid
from datetime import datetime

import grpc
from google.protobuf.empty_pb2 import Empty

from doublecloud._backoff import backoff_exponential_jittered_min_interval
from doublecloud._consts import OPERATIONS_PREFIX_MAP
from doublecloud._retry_interceptor import RetryInterceptor
from doublecloud.clickhouse.v1.operation_service_pb2 import (
    GetOperationRequest as chGetOperationRequest,
)
from doublecloud.clickhouse.v1.operation_service_pb2_grpc import (
    OperationServiceStub as chOperationServiceStub,
)
from doublecloud.kafka.v1.operation_service_pb2 import (
    GetOperationRequest as kfGetOperationRequest,
)
from doublecloud.kafka.v1.operation_service_pb2_grpc import (
    OperationServiceStub as kfOperationServiceStub,
)
from doublecloud.network.v1.operation_service_pb2 import (
    GetOperationRequest as vpcGetOperationRequest,
)
from doublecloud.network.v1.operation_service_pb2_grpc import (
    OperationServiceStub as vpcOperationServiceStub,
)
from doublecloud.operations import OperationError, OperationResult
from doublecloud.transfer.v1.operation_service_pb2 import (
    GetOperationRequest as dtGetOperationRequest,
)
from doublecloud.transfer.v1.operation_service_pb2_grpc import (
    OperationServiceStub as dtOperationServiceStub,
)
from doublecloud.v1.operation_pb2 import Operation


def is_valid_uuid(s):
    try:
        uuid.UUID(s)
        return True
    except ValueError:
        return False


def get_operation_service_stub(operation):
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["clickhouse"]):
        return chOperationServiceStub
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["kafka"]):
        return kfOperationServiceStub
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["transfer"]):
        return dtOperationServiceStub
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["transfer_endpoints"]):
        return dtOperationServiceStub
    if is_valid_uuid(operation.id):
        return vpcOperationServiceStub
    raise RuntimeError(f"Unknown operation type, operation: {operation}")


def get_operation_get_request(operation):
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["clickhouse"]):
        return chGetOperationRequest(operation_id=operation.id)
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["kafka"]):
        return kfGetOperationRequest(operation_id=operation.id)
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["transfer"]):
        return dtGetOperationRequest(operation_id=operation.id)
    if operation.id.startswith(OPERATIONS_PREFIX_MAP["transfer_endpoints"]):
        return dtGetOperationRequest(operation_id=operation.id)
    if is_valid_uuid(operation.id):
        return vpcGetOperationRequest(operation_id=operation.id)
    raise RuntimeError(f"Unknown operation type, operation_id: {operation.id}")


def operation_waiter(sdk, operation, timeout):
    retriable_codes = (
        grpc.StatusCode.UNAVAILABLE,
        grpc.StatusCode.RESOURCE_EXHAUSTED,
        grpc.StatusCode.INTERNAL,
    )
    # withstand server downtime for ~3.4 minutes with an exponential backof
    retry_interceptor = RetryInterceptor(
        max_retry_count=13,
        per_call_timeout=30,
        back_off_func=backoff_exponential_jittered_min_interval(),
        retriable_codes=retriable_codes,
    )
    return OperationWaiter(operation, retry_interceptor=retry_interceptor, timeout=timeout, sdk=sdk)


def wait_for_operation(sdk, operation, timeout):
    waiter = operation_waiter(sdk, operation, timeout)
    for _ in waiter:
        time.sleep(1)
    return waiter.operation


def get_operation_result(sdk, operation, meta_type=None, timeout=None, logger=None):
    if not logger:
        logger = logging.getLogger()
        logger.addHandler(logging.NullHandler())
    operation_result = OperationResult(operation)

    create_time = datetime.fromtimestamp(operation.create_time.seconds)
    message = (
        "Running double.cloud operation. ID: {id}. "
        + "Description: {description}. Created at: {create_time}. "
        + "Created by: {created_by}."
    )
    message = message.format(
        id=operation.id,
        description=operation.description,
        create_time=create_time,
        created_by=operation.created_by,
    )
    if meta_type and meta_type is not Empty:
        unpacked_meta = meta_type()
        operation.metadata.Unpack(unpacked_meta)
        operation_result.meta = unpacked_meta
        message += " Meta: {unpacked_meta}.".format(unpacked_meta=unpacked_meta)
    logger.info(message)
    result = wait_for_operation(sdk, operation, timeout=timeout)
    if result.error and result.error.code:
        error_message = (
            "Error double.cloud operation. ID: {id}. "
            + "Error code: {code}. Details: {details}. "
            + "Message: {message}."
        )
        error_message = error_message.format(
            id=result.id,
            code=result.error.code,
            details=result.error.details,
            message=result.error.message,
        )
        logger.error(error_message)
        raise OperationError(message=error_message, operation_result=result)

    logger.info(f"Done double.cloud operation. ID: {operation.id}.")
    return OperationResult(result)


class OperationWaiter:
    def __init__(self, operation, retry_interceptor=None, timeout=None, sdk=None, operation_service=None):
        self.__operation = operation
        self.__operation_service = operation_service
        self.__deadline = time.time() + timeout if timeout else None
        if sdk:
            try:
                stub = get_operation_service_stub(operation)
                self.__operation_service = sdk.client(stub, interceptor=retry_interceptor)
            except RuntimeError:
                pass
                # Some of services have already finished blocked operations
                # and they haven't additional operation services.
                # We will throw an exception in case of running operation without operation service.

    @property
    def operation(self):
        return self.__operation

    @property
    def done(self):
        if self.__operation is not None and self.__operation.status == Operation.Status.STATUS_DONE:
            # A shortcut for instantly finished operations
            return True
        if not self.__operation_service:
            raise RuntimeError(f"Unknown operation service for operation {self.__operation}")
        self.__operation = self.__operation_service.Get(get_operation_get_request(self.__operation))
        return self.__operation is not None and self.__operation.status == Operation.Status.STATUS_DONE

    def __iter__(self):
        return self

    def __next__(self):
        if self.done or self.__deadline is not None and time.time() >= self.__deadline:
            raise StopIteration()

    next = __next__  # for Python 2



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/kafka.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2
from doublecloud.transfer.v1.endpoint import parsers_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_parsers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,doublecloud/transfer/v1/endpoint/kafka.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\x1a.doublecloud/transfer/v1/endpoint/parsers.proto\"\x9a\x01\n\x16KafkaConnectionOptions\x12\x1f\n\ncluster_id\x18\x01 \x01(\tH\x00R\tclusterId\x12Q\n\non_premise\x18\x02 \x01(\x0b\x32\x30.doublecloud.transfer.v1.endpoint.OnPremiseKafkaH\x00R\tonPremiseB\x0c\n\nconnection\"w\n\x0eOnPremiseKafka\x12\x1f\n\x0b\x62roker_urls\x18\x01 \x03(\tR\nbrokerUrls\x12\x44\n\x08tls_mode\x18\x05 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\"\xa7\x01\n\tKafkaAuth\x12I\n\x04sasl\x18\x01 \x01(\x0b\x32\x33.doublecloud.transfer.v1.endpoint.KafkaSaslSecurityH\x00R\x04sasl\x12\x43\n\x07no_auth\x18\x02 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.NoAuthH\x00R\x06noAuthB\n\n\x08security\"\xbd\x01\n\x11KafkaSaslSecurity\x12\x12\n\x04user\x18\x01 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12N\n\tmechanism\x18\x03 \x01(\x0e\x32\x30.doublecloud.transfer.v1.endpoint.KafkaMechanismR\tmechanism\"\x89\x02\n\x0bKafkaSource\x12X\n\nconnection\x18\x01 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.KafkaConnectionOptionsR\nconnection\x12?\n\x04\x61uth\x18\x02 \x01(\x0b\x32+.doublecloud.transfer.v1.endpoint.KafkaAuthR\x04\x61uth\x12\x1d\n\ntopic_name\x18\x04 \x01(\tR\ttopicName\x12@\n\x06parser\x18\x07 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.ParserR\x06parser\"\x8b\x02\n\x0bKafkaTarget\x12X\n\nconnection\x18\x01 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.KafkaConnectionOptionsR\nconnection\x12?\n\x04\x61uth\x18\x02 \x01(\x0b\x32+.doublecloud.transfer.v1.endpoint.KafkaAuthR\x04\x61uth\x12\x61\n\x0etopic_settings\x18\x07 \x01(\x0b\x32:.doublecloud.transfer.v1.endpoint.KafkaTargetTopicSettingsR\rtopicSettings\"\x9d\x01\n\x18KafkaTargetTopicSettings\x12J\n\x05topic\x18\x01 \x01(\x0b\x32\x32.doublecloud.transfer.v1.endpoint.KafkaTargetTopicH\x00R\x05topic\x12#\n\x0ctopic_prefix\x18\x02 \x01(\tH\x00R\x0btopicPrefixB\x10\n\x0etopic_settings\"U\n\x10KafkaTargetTopic\x12\x1d\n\ntopic_name\x18\x01 \x01(\tR\ttopicName\x12\"\n\rsave_tx_order\x18\x02 \x01(\x08R\x0bsaveTxOrder*i\n\x0eKafkaMechanism\x12\x1f\n\x1bKAFKA_MECHANISM_UNSPECIFIED\x10\x00\x12\x1a\n\x16KAFKA_MECHANISM_SHA256\x10\x01\x12\x1a\n\x16KAFKA_MECHANISM_SHA512\x10\x02\x42\x46ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.kafka_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_KAFKAMECHANISM']._serialized_start=1602
  _globals['_KAFKAMECHANISM']._serialized_end=1707
  _globals['_KAFKACONNECTIONOPTIONS']._serialized_start=178
  _globals['_KAFKACONNECTIONOPTIONS']._serialized_end=332
  _globals['_ONPREMISEKAFKA']._serialized_start=334
  _globals['_ONPREMISEKAFKA']._serialized_end=453
  _globals['_KAFKAAUTH']._serialized_start=456
  _globals['_KAFKAAUTH']._serialized_end=623
  _globals['_KAFKASASLSECURITY']._serialized_start=626
  _globals['_KAFKASASLSECURITY']._serialized_end=815
  _globals['_KAFKASOURCE']._serialized_start=818
  _globals['_KAFKASOURCE']._serialized_end=1083
  _globals['_KAFKATARGET']._serialized_start=1086
  _globals['_KAFKATARGET']._serialized_end=1353
  _globals['_KAFKATARGETTOPICSETTINGS']._serialized_start=1356
  _globals['_KAFKATARGETTOPICSETTINGS']._serialized_end=1513
  _globals['_KAFKATARGETTOPIC']._serialized_start=1515
  _globals['_KAFKATARGETTOPIC']._serialized_end=1600
# @@protoc_insertion_point(module_scope)
